@@ -13,6 +13,7 @@ import logging
 import platform
 import yaml
 import stat
+from fosslight_util.help import print_package_version
 from fosslight_util.set_log import init_log
 import fosslight_util.constant as constant
 from fosslight_util.write_txt import write_txt_file
@@ -20,6 +21,7 @@ from fosslight_util.output_format import check_output_format, write_output_file
 from ._binary_dao import get_oss_info_from_db
 from ._binary import BinaryItem
 from ._help import print_help_msg
+from ._jar_analysis import ananlyze_jar_file, merge_binary_list
 
 _PKG_NAME = "fosslight_binary"
 logger = logging.getLogger(constant.LOGGER_NAME)
@@ -36,10 +38,17 @@ _REMOVE_DIR = ['.git']
 _REMOVE_DIR = [os.path.sep + dir_name + os.path.sep for dir_name in _REMOVE_DIR]
 _error_logs = []
 _root_path = ""
+_start_time = ""
+windows = False
+
+JAR_VUL_HEADER = {'BIN_FL_Binary': ['ID', 'Source Name or Path', 'OSS Name',
+                                    'OSS Version', 'License', 'Download Location',
+                                    'Homepage', 'Copyright Text', 'Exclude',
+                                    'Comment', 'Vulnerability Link']}
 
 
 def init(path_to_find_bin, output_file_name, format):
-    global _root_path, logger
+    global _root_path, logger, _start_time
 
     _json_ext = ".json"
     _start_time = datetime.now().strftime('%Y%m%d_%H%M%S')
@@ -84,12 +93,18 @@ def init(path_to_find_bin, output_file_name, format):
 
 
 def get_file_list(path_to_find):
-
     bin_list = []
     file_cnt = 0
+    found_jar = False
 
     for root, dirs, files in os.walk(path_to_find):
         for file in files:
+            file_lower_case = file.lower()
+            extension = file_lower_case.split(".")[-1]
+
+            if extension == 'jar':
+                found_jar = True
+
             directory = root + os.path.sep
             dir_path = directory.replace(_root_path, '', 1).lower()
             dir_path = os.path.sep + dir_path + os.path.sep
@@ -109,10 +124,10 @@ def get_file_list(path_to_find):
             bin_list.append(bin_item)
             file_cnt += 1
 
-    return file_cnt, bin_list
+    return file_cnt, bin_list, found_jar
 
 
-def find_binaries(path_to_find_bin, output_dir, format, _include_file_command, dburl=""):
+def find_binaries(path_to_find_bin, output_dir, format, dburl=""):
 
     _result_log, result_report, binary_txt_file, output_extension = init(
         path_to_find_bin, output_dir, format)
@@ -120,6 +135,9 @@ def find_binaries(path_to_find_bin, output_dir, format, _include_file_command, d
     total_bin_cnt = 0
     total_file_cnt = 0
     db_loaded_cnt = 0
+    success_to_write = False
+    writing_msg = ""
+    extended_header = {}
 
     try:
         if not os.path.isdir(path_to_find_bin):
@@ -127,8 +145,16 @@ def find_binaries(path_to_find_bin, output_dir, format, _include_file_command, d
                           result_log=_result_log,
                           exit=True)
 
-        total_file_cnt, file_list = get_file_list(path_to_find_bin)
-        total_bin_cnt, return_list = return_bin_only(file_list, _include_file_command)
+        total_file_cnt, file_list, found_jar = get_file_list(path_to_find_bin)
+        total_bin_cnt, return_list = return_bin_only(file_list)
+
+        # Run OWASP Dependency-check
+        if found_jar:
+            logger.info("Run OWASP Dependency-check to analyze .jar file")
+            owasp_items, vulnerability_items = ananlyze_jar_file(path_to_find_bin)
+            if owasp_items:
+                return_list = merge_binary_list(owasp_items, vulnerability_items, return_list)
+            extended_header = JAR_VUL_HEADER
 
         return_list, db_loaded_cnt = get_oss_info_from_db(return_list, dburl)
         return_list = sorted(return_list, key=lambda row: (row.bin_name))
@@ -145,29 +171,37 @@ def find_binaries(path_to_find_bin, output_dir, format, _include_file_command, d
         sheet_list = {}
         content_list = []
         for scan_item in return_list:
-            content_list.extend(scan_item.get_print_oss_report())
+            content_list.extend(scan_item.get_oss_report())
         sheet_list["BIN_FL_Binary"] = content_list
 
-        success_to_write, writing_msg = write_output_file(result_report, output_extension,
-                                                          sheet_list)
-        logger.info("Writing Output file(" + os.path.basename(result_report) + output_extension
-                    + "):" + str(success_to_write) + " " + writing_msg)
-        if success_to_write:
-            _result_log["Output file"] = result_report + output_extension
-
+        success_to_write, writing_msg = write_output_file(result_report, output_extension, sheet_list, extended_header)
     except Exception as ex:
         error_occured(error_msg=str(ex), exit=False)
 
+    # Print Result
+    try:
+        output_files = []
+        if output_extension == "":
+            output_extension = ".xlsx"
+            if not windows:
+                output_files.append(f"{result_report}.csv")
+        output_files.insert(0, f"{result_report}{output_extension}")
+
+        logger.info(f"Writing Output file ({output_files[0]}"
+                    f"):{success_to_write} {writing_msg}")
+        if success_to_write:
+            _result_log["Output file"] = output_files
+    except Exception as ex:
+        error_occured(error_msg=f"Print log:{ex}", exit=False)
+
     print_result_log(success=True, result_log=_result_log,
                      file_cnt=str(total_file_cnt), bin_file_cnt=str(total_bin_cnt),
                      auto_bin_cnt=str(db_loaded_cnt))
 
 
-def return_bin_only(file_list, include_file_type):
+def return_bin_only(file_list):
     bin_cnt = 0
     bin_list = []
-    if include_file_type != "":
-        include_file_type = include_file_type.lower()
     for file_item in file_list:
         file_with_path = file_item.bin_name
         file = file_item.binary_name_without_path
@@ -184,8 +218,6 @@ def return_bin_only(file_list, include_file_type):
                                        file_command_result.startswith(x)]
                     if len(removed_keyword) > 0:
                         continue
-                    if include_file_type != "" and include_file_type not in file_command_result:
-                        continue
 
                 error, error_msg = file_item.set_checksum_tlsh()
                 if error:
@@ -210,7 +242,7 @@ def print_result_log(success=True, result_log={}, file_cnt="", bin_file_cnt="",
     if "Running time" in result_log:
         start_time = result_log["Running time"]
     else:
-        start_time = ""
+        start_time = _start_time
     result_log["Running time"] = start_time + " ~ " + \
         datetime.now().strftime('%Y%m%d_%H%M%S')
     result_log["Execution result"] = 'Success' if success else 'Error occurred'
@@ -229,38 +261,39 @@ def print_result_log(success=True, result_log={}, file_cnt="", bin_file_cnt="",
 
 
 def main():
-
+    global windows
     argv = sys.argv[1:]
     output_dir = ""
     path_to_find_bin = ""
     format = ""
-    _include_file_command = ""
     db_url = ""
 
-    opts, args = getopt.getopt(argv, 'hp:a:o:f:d:')
-    for opt, arg in opts:
-        if opt == "-h":
-            print_help_msg()
-        elif opt == "-p":
-            path_to_find_bin = arg
-        elif opt == "-a":  # Target Architecture
-            _include_file_command = arg
-        elif opt == "-o":
-            output_dir = arg
-        elif opt == "-f":
-            format = arg
-        elif opt == "-d":
-            db_url = arg
+    try:
+        opts, args = getopt.getopt(argv, 'hvp:o:f:d:')
+        for opt, arg in opts:
+            if opt == "-h":
+                print_help_msg()
+            elif opt == "-v":
+                print_package_version(_PKG_NAME, "FOSSLight Binary Scanner Version:")
+            elif opt == "-p":
+                path_to_find_bin = arg
+            elif opt == "-o":
+                output_dir = arg
+            elif opt == "-f":
+                format = arg
+            elif opt == "-d":
+                db_url = arg
+    except Exception:
+        print_help_msg()
 
-    _windows = platform.system() == "Windows"
+    windows = platform.system() == "Windows"
     if path_to_find_bin == "":
-        if _windows:
+        if windows:
             path_to_find_bin = os.getcwd()
         else:
             print_help_msg()
 
-    find_binaries(path_to_find_bin, output_dir, format,
-                  _include_file_command, db_url)
+    find_binaries(path_to_find_bin, output_dir, format, db_url)
 
 
 if __name__ == '__main__':
